amplify_firehose library

Amplify Amazon Data Firehose client for Flutter.

Classes

AmplifyFirehoseClient
Client for recording and streaming data to Amazon Data Firehose.
AmplifyFirehoseClientOptions
Configuration options for AmplifyFirehoseClient.
ClearCacheData
Data returned from a clearCache operation.
FirehoseClient
Amazon Data Firehose
FlushData
Data returned from a flush operation.
FlushInterval
A flush strategy that triggers automatic flushes at a fixed interval.
FlushNone
A flush strategy that disables automatic flushing.
FlushStrategy
Determines when automatic flushing of cached records occurs.
PutRecordBatchInput
PutRecordBatchOutput
PutRecordBatchResponseEntry
Contains the result for an individual record from a PutRecordBatch request. If the record is successfully added to your Firehose stream, it receives a record ID. If the record fails to be added to your Firehose stream, the result includes an error code and an error message.
RecordData
Data returned from a record operation.

Exceptions / Errors

AmplifyFirehoseException
Base exception for Amplify Firehose errors.
FirehoseClientClosedException
Thrown when an operation is attempted on a closed client.
FirehoseLimitExceededException
Thrown when the local cache is full.
FirehoseStorageException
Thrown when a local cache/database error occurs.
FirehoseUnknownException
Catch-all for unexpected errors.
FirehoseValidationException
Thrown when record input validation fails (e.g. oversized record).